# Contributng

How to contribute :

1. Install in developer mode

```bash
pip install -e .[dev]
```

2. Install pre-commit hooks

```bash
pre-commit install
```

3. Make changes and run tests

```bash
pytest tests
```

4. Make a pull request + get it reviewed + merge
